@@ -40,26 +40,26 @@ areColors <- function(col) {
 #' function to verify all rasters in list overlap with the
 #' template raster.
 #'
-#' @param a The first `Raster*` object
+#' @param a The first `SpatRaster` object
 #'
-#' @param b The second `Raster*` object
+#' @param b The second `SpatRaster` object
 #'
 #' @return A logical vector stating whether the two
 #' inputs overlap
 #'
 #' @examples
 #'
-#' library(raster)
-#' rast1 <- raster(ncol=10, nrow=10)
+#' library(terra)
+#' rast1 <- rast(ncol=10, nrow=10)
 #' values(rast1) <- rep(0:1, 50)
 #'
-#' rast2 <- raster(ncol=10, nrow=10)
+#' rast2 <- rast(ncol=10, nrow=10)
 #' values(rast2) <- c(rep(0, 50), rep(1,50))
 #'
 #' testIntersection(rast1, rast2)
 #'
-#' rast1 <- crop(rast1, extent(10, 20, 30, 40))
-#' rast2 <- crop(rast2, extent(-20, -10, -40, -30))
+#' rast1 <- crop(rast1, ext(10, 20, 30, 40))
+#' rast2 <- crop(rast2, ext(-20, -10, -40, -30))
 #'
 #' testIntersection(rast1, rast2)
 #'
@@ -89,8 +89,8 @@ testIntersection <- function(a,b){
 #' name to be used in the plot title.
 #'
 #' @param land An optional coastline polygon shapefile
-#' of type `sf` to provide geographic context for the
-#' occurrence points.
+#' of types `sf` or `SpatRaster` to provide geographic
+#' context for the occurrence points.
 #'
 #' @param ptCol Color for occurrence points on map
 #'
@@ -159,11 +159,19 @@ pointMap <- function(occs, spName, land = NA,
     return(NULL)
   }
 
-  if(!any(is.na(land[[1]]), "sf" %in% class(land))){
-    warning(paste0("'land' must either be NA or of class 'sf'."))
+  if(!any(is.na(land[[1]]),
+          "sf" %in% class(land),
+          "SpatVector" %in% class(land))){
+    warning(paste0("'land' must be NA or of class 'sf' or 'SpatVector'."))
     return(NULL)
   }
 
+  if(!any(is.na(land))){
+    if(!("sf" %in% class(land))){
+      land <- sf::st_as_sf(land)
+    }
+  }
+
   colVec <- c(ptCol, landCol, waterCol)
   colTest <- areColors(colVec)
 
@@ -201,8 +209,8 @@ pointMap <- function(occs, spName, land = NA,
         coord_sf(xlim = c(min(occs[[xIndex]]), max(occs[[xIndex]])),
                  ylim = c(min(occs[[yIndex]]), max(occs[[yIndex]])),
                  expand = .05, ) +
-        xlab("Longitude") +
-        ylab("Latitude") +
+        xlab("") +
+        ylab("") +
         ggtitle(paste0(spName, ", ", nrow(occs), " points"))
   }else{
     point_map <- ggplot(mapping = mapping) +
@@ -214,8 +222,8 @@ pointMap <- function(occs, spName, land = NA,
       coord_sf(xlim = c(min(occs[[xIndex]]), max(occs[[xIndex]])),
                ylim = c(min(occs[[yIndex]]), max(occs[[yIndex]])),
                expand = .05, ) +
-      xlab("Longitude") +
-      ylab("Latitude") +
+      xlab("") +
+      ylab("") +
       ggtitle(paste0(spName, ", ", nrow(occs), " points"))
   }
   return(point_map)
@@ -239,8 +247,8 @@ pointMap <- function(occs, spName, land = NA,
 #' name to be used in the plot title.
 #'
 #' @param land An optional coastline polygon shapefile
-#' of type `sf` to provide geographic context for the
-#' occurrence points.
+#' of types `sf` or `SpatRaster` to provide geographic
+#' context for the occurrence points.
 #'
 #' @param occs1Col Color for occurrence points on map
 #'
@@ -345,11 +353,19 @@ pointCompMap <- function(occs1, occs2,
     return(NULL)
   }
 
-  if(!any(is.na(land[[1]]), "sf" %in% class(land))){
-    warning(paste0("'land' must either be NA or of class 'sf'."))
+  if(!any(is.na(land[[1]]),
+          "sf" %in% class(land),
+          "SpatVector" %in% class(land))){
+    warning(paste0("'land' must be NA or of class 'sf' or 'SpatVector'."))
     return(NULL)
   }
 
+  if(!any(is.na(land))){
+    if(!("sf" %in% class(land))){
+      land <- sf::st_as_sf(land)
+    }
+  }
+
   if (!is.logical(verbose)) {
     warning(message("Argument 'verbose' is not of type 'logical'.\n"))
     return(NULL)
@@ -380,7 +396,7 @@ pointCompMap <- function(occs1, occs2,
   interp1 <- colParse1$reportMessage
 
   if(verbose){
-    message(interp1)
+    message(paste("First set of occurrences: ", interp1))
   }
 
   colNames2 <- colnames(occs2)
@@ -393,7 +409,7 @@ pointCompMap <- function(occs1, occs2,
   interp2 <- colParse2$reportMessage
 
   if(verbose){
-    message(interp2)
+    message(paste("Second set of occurrences: ", interp2))
   }
 
   if(!all(c(colnames(occs1)[[xIndex1]] == colnames(occs2)[[xIndex2]],
@@ -405,16 +421,16 @@ pointCompMap <- function(occs1, occs2,
 
   # Where the function actually starts
   occsBoth <- NA
-  occsBoth <- dplyr::inner_join(occs2[,c(xIndex2, yIndex2)],
-                                occs1[,c(xIndex1, yIndex1)]) %>%
+  occsBoth <- suppressMessages(dplyr::inner_join(occs2[,c(xIndex2, yIndex2)],
+                                occs1[,c(xIndex1, yIndex1)], multiple = "all") %>%
     dplyr::distinct() %>%
-    dplyr::mutate(source = "both")
-  occs1 <- dplyr::anti_join(occs1[,c(xIndex1, yIndex1)],occsBoth) %>%
+    dplyr::mutate(source = "both"))
+  occs1 <- suppressMessages(dplyr::anti_join(occs1[,c(xIndex1, yIndex1)],occsBoth) %>%
     dplyr::distinct() %>%
-    dplyr::mutate(source = occs1Name)
-  occs2 <- dplyr::anti_join(occs2[,c(xIndex2, yIndex2)],occsBoth) %>%
+    dplyr::mutate(source = occs1Name))
+  occs2 <- suppressMessages(dplyr::anti_join(occs2[,c(xIndex2, yIndex2)],occsBoth) %>%
     dplyr::distinct() %>%
-    dplyr::mutate(source = occs2Name)
+    dplyr::mutate(source = occs2Name))
 
   colParse1 <- columnParse(occs1)
   xIndex1 <- colParse1$xIndex
@@ -464,8 +480,8 @@ pointCompMap <- function(occs1, occs2,
              ylim = c(min(occ_dat[[occ_datIndices$yIndex]]),
                       max(occ_dat[[occ_datIndices$yIndex]])),
              expand = .05, ) +
-    xlab("Longitude") +
-    ylab("Latitude") +
+    xlab("") +
+    ylab("") +
     labs(
       title = paste0("***", spName,"***<p>
     <span style='color:", agreeCol,";'>Overlapping</span>,
@@ -487,8 +503,8 @@ pointCompMap <- function(occs1, occs2,
                ylim = c(min(occ_dat[[occ_datIndices$yIndex]]),
                         max(occ_dat[[occ_datIndices$yIndex]])),
                expand = .05, ) +
-      xlab("Longitude") +
-      ylab("Latitude") +
+      xlab("") +
+      ylab("") +
       labs(
         title = paste0("***", spName,"***<p>
     <span style='color:", agreeCol,";'>Overlapping</span>,
@@ -605,33 +621,23 @@ blendColor <- function( col1 = "#1b9e777F", col2 = "#7570b37F") {
 
 #' @title Comparative raster mapping
 #'
-#' @description A convenient wrapper around `spplot`
+#' @description A convenient wrapper around `terra::plot`
 #' to generate formatted plots comparing two rasters.
 #' This is used in the context of voluModel to
 #' overlay semi-transparent distributions (coded as 1)
 #' in two different `RasterLayers`.
 #'
-#' @param rast1 A single `RasterLayer` showing the
+#' @param rast1 A single `SpatRaster` showing the
 #' distribution of the species corresponding to
 #' `rast1Name`. Should have values of 0 (absence)
 #' and 1 (presence). Can also be `NULL`.
 #'
-#' @param rast2 A single `RasterLayer` showing the
+#' @param rast2 A single `SpatRaster` showing the
 #' distribution of the species corresponding to
 #' `rast2Name`. Should have values of 0 (absence)
 #' and 1 (presence). Must match the extent and
 #' resolution of `rast1`. Can also be `NULL.`
 #'
-#' @param rast1Name A character string with the name
-#' of the species depicted in `rast1`.
-#'
-#' @param rast2Name A character string with the name
-#' of the species depicted in `rast2`.
-#'
-#' @param land An optional coastline polygon shapefile
-#' of type `sf` to provide geographic context for the
-#' occurrence points.
-#'
 #' @param col1 Color for `rast1` presences
 #'
 #' @param col2 Color for `rast2` presences
@@ -647,34 +653,37 @@ blendColor <- function( col1 = "#1b9e777F", col2 = "#7570b37F") {
 #' @param landCol Color for land on map.
 #'
 #' @param land An optional coastline polygon shapefile
-#' of type `sf` to provide geographic context for the
-#' occurrence points.
+#' of types `sf` or `SpatRaster` to provide geographic
+#' context for the occurrence points.
 #'
 #' @param title A title for the plot.
 #'
-#' @param ... Additional optional arguments to pass to
-#' `spplot` initial plot object.
+#' @param graticule Do you want a grid of lon/lat lines?
 #'
-#' @return A plot of class `trellis` overlaying mapped,
+#' @param ... Additional optional arguments to pass to
+#' `terra::plot()`.
+#'
+#' @return A plot of class `recordedplot` overlaying mapped,
 #' semitransparent extents of the input rasters
 #'
 #' @note The extents of `rast1` and `rast2`
 #' must match.
 #'
 #' @examples
-#' library(raster)
-#' rast1 <- raster(ncol=10, nrow=10)
+#' library(terra)
+#' rast1 <- rast(ncol=10, nrow=10)
 #' values(rast1) <- rep(0:1, 50)
 #'
-#' rast2 <- raster(ncol=10, nrow=10)
+#' rast2 <- rast(ncol=10, nrow=10)
 #' values(rast2) <- c(rep(0, 50), rep(1,50))
 #'
 #' rasterComp(rast1 = rast1, rast2 = rast2)
 #'
-#' @import raster
-#' @importFrom latticeExtra as.layer
+#' @import terra
+#' @importFrom grDevices recordPlot
+#' @importFrom graphics legend
 #'
-#' @seealso \code{\link[raster:spplot]{spplot}}
+#' @seealso \code{\link[terra:plot]{plot}}
 #'
 #' @keywords plotting
 #' @export
@@ -683,16 +692,11 @@ rasterComp <- function(rast1 = NULL, rast2 = NULL,
                        col1 = "#1b9e777F", col2 = "#7570b37F",
                        rast1Name = "Set 1", rast2Name = "Set 2",
                        land = NA, landCol = "black",
-                       title = "A Raster Comparison", ...){
+                       title = "A Raster Comparison",
+                       graticule = TRUE, ...){
 
   args <- list(...)
 
-  if("maxpixels" %in% names(args)){
-    maxpixels <- args$maxpixels
-  } else{
-    maxpixels <- 50000
-  }
-
   colVec <- c(col1, col2, landCol)
   colTest <- areColors(colVec)
 
@@ -702,8 +706,10 @@ rasterComp <- function(rast1 = NULL, rast2 = NULL,
     return(NULL)
   }
 
-  if(!any(is.na(land[[1]]), "sf" %in% class(land))){
-    warning(paste0("'land' must either be NA or of class 'sf'."))
+  if(!any(is.na(land[[1]]),
+          "sf" %in% class(land),
+          "SpatVector" %in% class(land))){
+    warning(paste0("'land' must be NA or of class 'sf' or 'SpatVector'."))
     return(NULL)
   }
 
@@ -715,10 +721,16 @@ rasterComp <- function(rast1 = NULL, rast2 = NULL,
     return(NULL)
   }
 
-  if(any(all(!inherits(rast1, what = "RasterLayer"), !is.null(rast1)),
-         all(!inherits(rast2, what = "RasterLayer"), !is.null(rast2)))){
+  if(!is.logical(graticule)){
+    warning(paste0("'graticule' must be 'TRUE' or 'FALSE'.\n"))
+    return(NULL)
+  }
+
+
+  if(any(all(!inherits(rast1, what = "SpatRaster"), !is.null(rast1)),
+         all(!inherits(rast2, what = "SpatRaster"), !is.null(rast2)))){
     warning(paste0("'rast1' and 'rast2', must either be objects of type
-                   'RasterLayer' or NULL.\n"))
+                   'SpatRaster' or NULL.\n"))
     return(NULL)
   }
 
@@ -732,9 +744,9 @@ rasterComp <- function(rast1 = NULL, rast2 = NULL,
       values(rast2) <- 0
       message(paste0("'rast2' was null. Replaced with blank raster."))
     } else{
-      rast1 <- raster(ncol=10, nrow=10)
+      rast1 <- rast(ncol=10, nrow=10)
       values(rast1) <- 0
-      rast2 <- raster(ncol=10, nrow=10)
+      rast2 <- rast(ncol=10, nrow=10)
       values(rast2) <- 0
       message(paste0("Both 'rast1' and 'rast2' were null.\n",
                      "They were replaced with blank rasters."))
@@ -747,69 +759,49 @@ rasterComp <- function(rast1 = NULL, rast2 = NULL,
               transpColor(col2, percent = 50),
               blendColor(transpColor(col1, percent = 50),
                          transpColor(col2, percent = 50)))
-  if(any(is.na(land))){
-    if(all(cellStats(rast2, sum) > 0, cellStats(rast1, sum) > 0)){
-      spplot(rast1, col.regions = myCols[c(1,2)], cuts = 1, colorkey = FALSE,
-             key=list(space="right", points=list(pch = 22, cex = 2,
-                                                 fill=c("white",myCols[c(2:4)])),
-                      text=list(c("Neither", rast1Name, rast2Name, "Both"))),
-             col="transparent", main = title,
-             par.settings = list(mai = c(0,0,0,0)),
-             maxpixels = maxpixels) +
-        as.layer(spplot(rast2, col.regions = myCols[c(1,3)],
-                        cuts = 1, col="transparent"))
-    } else if(cellStats(rast2, sum) == 0){
-      spplot(rast1, col.regions = myCols[c(1,2)], cuts = 1, colorkey = FALSE,
-             key=list(space="right", points=list(pch = 22, cex = 2,
-                                                 fill=c("white",myCols[c(2:4)])),
-                      text=list(c("Neither", rast1Name, rast2Name, "Both"))),
-             col="transparent", main = title,
-             par.settings = list(mai = c(0,0,0,0)),
-             maxpixels = maxpixels)
-    } else{
-      spplot(rast2, col.regions = myCols[c(1,3)], cuts = 1, colorkey = FALSE,
-             key=list(space="right", points=list(pch = 22, cex = 2,
-                                                 fill=c("white",myCols[3])),
-                      text=list(c("Neither", rast2Name))),
-             col="transparent", main = title,
-             maxpixels = maxpixels,
-             par.settings = list(mai = c(0,0,0,0)))
-    }
-  } else {
-    if (all(cellStats(rast2, sum) > 0, cellStats(rast1, sum) > 0)){
-      spplot(rast1, col.regions = myCols[c(1,2)],
-             cuts = 1, colorkey = FALSE,
-             key=list(space="right",
-                      points=list(pch = 22, cex = 2,
-                                  fill=c("white", myCols[c(2:4)])),
-                      text=list(c("Neither", rast1Name, rast2Name, "Both"))),
-             col="transparent",  main = title,
-             maxpixels = maxpixels,
-             sp.layout=list(as(land, "Spatial"), fill=landCol, first=FALSE),
-             par.settings = list(mai = c(0,0,0,0))) +
-        as.layer(spplot(rast2, col.regions = myCols[c(1,3)], cuts = 1, col="transparent"))
-    } else if (cellStats(rast2, sum) == 0){
-      spplot(rast1, col.regions = myCols[c(1,2)],
-             cuts = 1, colorkey = FALSE,
-             key=list(space="right",
-                      points=list(pch = 22, cex = 2,
-                                  fill=c("white",myCols[2])),
-                      text=list(c("Neither", rast1Name))),
-             col="transparent", main = title,
-             maxpixels = maxpixels,
-             sp.layout=list(as(land, "Spatial"), fill=landCol, first=FALSE),
-             par.settings = list(mai = c(0,0,0,0)))
-    } else{
-      spplot(rast2, col.regions = myCols[c(1,3)], cuts = 1, colorkey = FALSE,
-             key=list(space="right", points=list(pch = 22, cex = 2,
-                                                 fill=c("white",myCols[3])),
-                      text=list(c("Neither", rast2Name))),
-             col="transparent", main = title,
-             maxpixels = maxpixels,
-             sp.layout=list(as(land, "Spatial"), fill=landCol, first=FALSE),
-             par.settings = list(mai = c(0,0,0,0)))
-    }
+
+  plot(rast1, col = c(myCols[1], myCols[2]), legend = FALSE, axes = TRUE, mar = c(2,2,3,2))
+  plot(rast2, col = c(myCols[1], myCols[3]), legend = FALSE, axes = FALSE, add = T)
+
+  if(graticule){
+    grat <- graticule(lon = seq(-180, 180, 10), lat = seq(-90,90,10), crs = crs(rast1))
+    plot(grat, col="gray50", add = TRUE)
   }
+
+  if(!any(is.na(land))){
+    if(!("SpatVector" %in% class(land))){
+      land <- vect(land)
+    }
+    plot(land, col = landCol, add = TRUE)
+  }
+
+  title(main = title, cex.main = 1.1)
+
+  # Legend plotting
+  if(sum(terra::minmax(rast1), terra::minmax(rast2)) == 0){
+    legend(x = round(xmax(rast1)) + 1, y = round(ymax(rast1)) + 1,
+           bty = "n",
+           legend = c("Neither"),
+           fill = myCols[1])
+  }else if(terra::minmax(rast1)[2] == 0){
+    legend(x = round(xmax(rast1)) + 1, y = round(ymax(rast1)) + 1,
+           bty = "n",
+           legend = c("Neither", rast2Name),
+           fill = myCols[c(-2, -4)])
+  }else if(terra::minmax(rast2)[2] == 0){
+    legend(x = round(xmax(rast1)) + 1, y = round(ymax(rast1)) + 1,
+           bty = "n",
+           legend = c("Neither", rast1Name),
+           fill = myCols[c(-3, -4)])
+  } else{
+    legend(x = round(xmax(rast1)) + 1, y = round(ymax(rast1)) + 1,
+           bty = "n",
+           legend = c("Neither", rast1Name, rast2Name, "Both"),
+           fill = myCols)
+  }
+
+  plotResult <- recordPlot()
+  return(plotResult)
 }
 
 #' @title Diversity stack
@@ -820,20 +812,20 @@ rasterComp <- function(rast1 = NULL, rast2 = NULL,
 #' estimate of species richness that matches the extent and
 #' resolution of a template.
 #'
-#' @param rasterList A `list` of `RasterLayer` objects, which
+#' @param rasterList A `list` of `SpatRaster` objects, which
 #' are interpreted as species distributions (1 = presence,
 #' 0 = absence).
 #'
-#' @param template A `RasterLayer` with the desired extent
+#' @param template A `SpatRaster` with the desired extent
 #'
-#' @return A `RasterLayer`
+#' @return A `SpatRaster`
 #'
 #' @examples
-#' library(raster)
-#' rast1 <- raster(ncol=10, nrow=10)
+#' library(terra)
+#' rast1 <- rast(ncol=10, nrow=10)
 #' values(rast1) <- rep(0:1, 50)
 #'
-#' rast2 <- raster(ncol=10, nrow=10)
+#' rast2 <- rast(ncol=10, nrow=10)
 #' values(rast2) <- c(rep(0, 50), rep(1,50))
 #'
 #' rastList <- list(rast1, rast2)
@@ -842,7 +834,7 @@ rasterComp <- function(rast1 = NULL, rast2 = NULL,
 #' result
 #' plot(result)
 #'
-#' @import raster
+#' @importFrom terra rast resample
 #' @keywords plotting
 #' @export
 
@@ -853,25 +845,24 @@ diversityStack <- function(rasterList, template){
   }
 
   if(!all(unlist(lapply(rasterList,
-                        function(X){grepl("Raster*", class(X))})))){
-    warning(paste0("All objects in 'rasterList' must be of class 'Raster*'.\n"))
+                        function(X){grepl("SpatRaster", class(X))})))){
+    warning(paste0("All objects in 'rasterList' must be of class 'SpatRaster'.\n"))
     return(NULL)
   }
 
-  if(!grepl("Raster*", class(template))){
-    warning(paste0("'template' must be of class 'Raster*'.\n"))
+  if(!grepl("SpatRaster", class(template))){
+    warning(paste0("'template' must be of class 'SpatRaster'.\n"))
     return(NULL)
   }
 
-  diversityRaster <- raster(nrows = template@nrows, ncol = template@ncols,
-                            ext = template@extent, crs = template@crs)
+  diversityRaster <- template
   values(diversityRaster) <- 0
 
-  for(i in 1:length(rasterList)){
-    temp <- rasterList[[i]]
+  for(i in rasterList){
+    temp <- i
     if(testIntersection(temp,template)){
-      temp <- raster::resample(temp, template)
-      temp[is.na(temp[])] <- 0
+      temp <- terra::resample(temp, template, method = "near")
+      temp <- subst(temp, NA, 0)
       diversityRaster <- diversityRaster + temp
     }
   }
@@ -880,54 +871,59 @@ diversityStack <- function(rasterList, template){
 
 #' @title Single raster plot
 #'
-#' @description A convenient wrapper around `spplot`
+#' @description A convenient wrapper around `ggplot`
 #' to generate a formatted plot of a single raster.
 #'
-#' @param rast A single `Raster*` layer on a continuous
+#' @param rast A single `SpatRaster` layer on a continuous
 #' scale.
 #'
 #' @param land An optional coastline polygon shapefile
-#' of type `sf` to provide geographic context for the
-#' occurrence points.
+#' of types `sf` or `SpatRaster` to provide geographic
+#' context for the occurrence points.
 #'
 #' @param landCol Color for land on map.
 #'
+#' @param scaleRange Optional numeric vector containing
+#' maximum and minimum values for color scale. Helpful
+#' when making multiple plots for comparison. Defaults
+#' to minimum and maximum of input `rast`.
+#'
 #' @param title A title for the plot.
 #'
-#' @param ... Additional optional arguments to pass to
-#' `spplot` initial plot object or `viridis`.
+#' @param verbose `logical`. Switching to `FALSE` mutes message alerting
+#' user if input `rast` values exceed a specified `scaleRange`.
 #'
-#' @return A plot of class `trellis` mapping the values
-#' of the input raster layer
+#' @param graticule `logical`. Do you want a grid of lon/lat lines?
+#'
+#' @param ... Additional optional arguments to pass to
+#' `plot` initial plot object or `viridis`.
+#'
+#' @return A plot of mapping the values of the input raster layer
 #'
 #' @examples
-#' library(raster)
-#' rast <- raster(ncol=10, nrow=10)
+#' library(terra)
+#' rast <- rast(ncol=10, nrow=10)
 #' values(rast) <- seq(0,99, 1)
 #'
 #' oneRasterPlot(rast = rast)
 #'
-#' @import raster
+#' @import terra
 #' @importFrom viridisLite viridis
-#' @importFrom latticeExtra as.layer
 #'
-#' @seealso \code{\link[viridisLite:viridis]{viridis}} \code{\link[raster:spplot]{spplot}}
+#' @seealso \code{\link[viridisLite:viridis]{viridis}} \code{\link[ggplot2:ggplot]{ggplot}}
 #'
 #' @keywords plotting
 #' @export
 
 oneRasterPlot <- function(rast,
                           land = NA, landCol = "black",
-                          title = "A Raster", ...){
+                          scaleRange = NA,
+                          graticule = TRUE,
+                          title = "A Raster",
+                          verbose = TRUE, ...){
   #Input processing
   args <- list(...)
 
-  if("maxpixels" %in% names(args)){
-    maxpixels <- args$maxpixels
-  } else{
-    maxpixels <- 10000
-  }
-
   if("alpha" %in% names(args)){
     alpha <- args$alpha
   } else{
@@ -946,14 +942,47 @@ oneRasterPlot <- function(rast,
     n = 11
   }
 
+  if("varName" %in% names(args)){
+    varName <- args$varName
+  } else{
+    varName <- "Variable"
+  }
+
+  if("legendRound" %in% names(args)){
+    legendRound <- args$legendRound
+  } else{
+    legendRound <- 2
+  }
+
   # Input error checking
-  if(!grepl("Raster*", class(rast))){
-    warning(paste0("'rast' must be of class 'Raster*'.\n"))
+  if(!grepl("SpatRaster", class(rast))){
+    warning(paste0("'rast' must be of class 'SpatRaster'.\n"))
     return(NULL)
   }
 
-  if(!any(is.na(land), "sf" %in% class(land))){
-    warning(paste0("'land' must either be NA or of class 'sf'."))
+  if(!any(is.na(land[[1]]),
+          "sf" %in% class(land),
+          "SpatVector" %in% class(land))){
+    warning(paste0("'land' must be NA or of class 'sf' or 'SpatVector'."))
+    return(NULL)
+  }
+
+  if(!any(is.na(land))){
+    if(!("sf" %in% class(land))){
+      land <- sf::st_as_sf(land)
+    }
+  }
+
+  if(!all(is.na(scaleRange))){
+    if(!all(any("numeric" %in% class(scaleRange)),
+            length(scaleRange) == 2)){
+      warning(paste0("'scaleRange' must either be NA or\na numeric vector of length 2."))
+      return(NULL)
+    }
+  }
+
+  if (!is.logical(graticule)) {
+    warning(message("Argument 'graticule' is not of type 'logical'.\n"))
     return(NULL)
   }
 
@@ -969,23 +998,63 @@ oneRasterPlot <- function(rast,
     return(NULL)
   }
 
-  #Function body
-  at <- seq(from = cellStats(rast, min), to = cellStats(rast, max),
-            by = (cellStats(rast, max)-cellStats(rast, min))/n)
-
-  if(any(is.na(land))){
-    spplot(rast, col = "transparent",
-           col.regions = viridis(n = n, alpha = alpha,
-                                 option = option),
-           at = at, main = title,
-           maxpixels = maxpixels)
-  } else {
-    spplot(rast, col = viridis(n = n, alpha = alpha,
-                                 option = option),
-           at = at, main = title,
-           maxpixels = maxpixels,
-           sp.layout=list(as(land, "Spatial"), fill=landCol, first=FALSE))
+  if (!is.logical(verbose)) {
+    warning(message("Argument 'verbose' is not of type 'logical'.\n"))
+    return(NULL)
   }
+
+  #Function body
+  if(any(is.na(scaleRange))){
+    begin <- unlist(global(rast, min, na.rm = TRUE))
+    end <- unlist(global(rast, max, na.rm = TRUE))
+  } else if(any(global(rast, min, na.rm = TRUE) < min(scaleRange),
+                global(rast, max, na.rm = TRUE) > max(scaleRange))){
+    begin <- unlist(global(rast, min, na.rm = TRUE))
+    end <- unlist(global(rast, max, na.rm = TRUE))
+
+    if(verbose){
+      message(paste0("Input raster extremes exceed specified scale range.\n",
+                     "Using input raster max and min instead."))
+    }
+
+  } else{
+    begin <- min(scaleRange)
+    end <- max(scaleRange)
+  }
+
+  colVals <- seq(from = begin, to = end, by = (end-begin)/n)
+  colVals <- data.frame("from" = colVals[1:(length(colVals)-1)],
+                        "to" = colVals[2:length(colVals)],
+                        "color" = viridisLite::viridis(n = n, alpha = 1, option = option))
+
+  plot(rast,
+       col = colVals,
+       legend = FALSE, mar = c(2,2,3,2), axes = TRUE)
+
+  if(graticule){
+    grat <- graticule(lon = seq(-180, 180, 10), lat = seq(-90,90,10), crs = crs(rast))
+    plot(grat, col="gray50", add = TRUE)
+  }
+
+  if(!any(is.na(land))){
+    if(!("SpatVector" %in% class(land))){
+      land <- vect(land)
+    }
+    plot(land, col = landCol, add = TRUE)
+  }
+
+  legend(x = round(xmax(rast)) + 1, y = round(ymax(rast)) + 1,
+         title = varName,
+         bty = "n",
+         legend = paste0(round(colVals[,1], legendRound),
+                         " - ", round(colVals[,2], legendRound)),
+         fill = colVals[,3])
+
+  title(main = title, cex.main = 1.1)
+
+  finalPlot <- recordPlot()
+
+  return(finalPlot)
 }
 
 #' @title Plotting 3D model in 2D
@@ -996,21 +1065,22 @@ oneRasterPlot <- function(rast,
 #' deeper. The more saturated the color, the more layers
 #' with suitable habitat.
 #'
-#' @param rast A `Raster*` with the 3D presence/absence
+#' @param rast A `SpatRaster` vector with the 3D presence/absence
 #' distribution of a species (interpreted as 1 = presence,
-#' 0 = absence). This could be a `RasterBrick` or a
-#' `RasterStack`.
+#' 0 = absence).
 #'
 #' @param land An optional coastline polygon shapefile
-#' of type `sf` to provide geographic context for the
-#' occurrence points.
+#' of types `sf` or `SpatRaster` to provide geographic
+#' context for the occurrence points.
 #'
 #' @param landCol Color for land on map.
 #'
 #' @param title A title for the plot. If not title is
 #' supplied, the title "Suitability from (MINIMUM
 #' DEPTH) to (MAXIMUM DEPTH)" is inferred from
-#' names of `RasterStack`.
+#' names of `rast`.
+#'
+#' @param graticule Do you want a grid of lon/lat lines?
 #'
 #' @param ... Additional optional arguments.
 #'
@@ -1018,54 +1088,49 @@ oneRasterPlot <- function(rast,
 #' want to plot.
 #'
 #' @examples
-#' library(raster)
+#' library(terra)
 #'
-#' rast1 <- raster(ncol=10, nrow=10)
+#' rast1 <- rast(ncol=10, nrow=10)
 #' values(rast1) <- rep(0:1, 50)
 #'
-#' rast2 <- raster(ncol=10, nrow=10)
+#' rast2 <- rast(ncol=10, nrow=10)
 #' values(rast2) <- c(rep(0, 50), rep(1,50))
 #'
-#' rast3 <- raster(ncol=10, nrow=10)
+#' rast3 <- rast(ncol=10, nrow=10)
 #' values(rast3) <- rep(c(1,0,0,1), 25)
 #'
-#' distBrick <- brick(rast1, rast2, rast3)
+#' distBrick <- c(rast1, rast2, rast3)
 #'
 #' plotLayers(distBrick)
 #'
-#' @import raster
-#' @importFrom viridisLite viridis
-#' @importFrom latticeExtra as.layer
+#' @import terra
+#' @importFrom grDevices recordPlot
 #'
-#' @seealso \code{\link[viridisLite:viridis]{viridis}} \code{\link[raster:spplot]{spplot}}
+#' @seealso \code{\link[viridisLite:viridis]{viridis}}
 #'
 #' @keywords plotting
 #'
-#' @return A plot of class `trellis`
+#' @return A plot of class `recordedplot`
 #'
 #' @export
 
-
 plotLayers <- function(rast,
                       land = NA, landCol = "black",
-                      title = NULL, ...){
+                      title = NULL,
+                      graticule = TRUE, ...){
   #Input processing
   args <- list(...)
 
-  if("maxpixels" %in% names(args)){
-    maxpixels <- args$maxpixels
-  } else{
-    maxpixels <- 10000
-  }
-
   # Input error checking
-  if(!grepl("Raster*", class(rast))){
-    warning(paste0("'rast' must be of class 'Raster*'.\n"))
+  if(!grepl("SpatRaster", class(rast))){
+    warning(paste0("'rast' must be of class 'SpatRaster'.\n"))
     return(NULL)
   }
 
-  if(!any(is.na(land), "sf" %in% class(land))){
-    warning(paste0("'land' must either be NA or of class 'sf'."))
+  if(!any(is.na(land[[1]]),
+          "sf" %in% class(land),
+          "SpatVector" %in% class(land))){
+    warning(paste0("'land' must be NA or of class 'sf' or 'SpatVector'."))
     return(NULL)
   }
 
@@ -1076,45 +1141,51 @@ plotLayers <- function(rast,
     return(NULL)
   }
 
+  if (!is.logical(graticule)) {
+    warning(message("Argument 'graticule' is not of type 'logical'.\n"))
+    return(NULL)
+  }
+
   if(is.null(title)){
    title <- paste0("Suitability from ",
            names(rast)[[1]]," to ",
-           names(rast)[[nlayers(rast)]])
+           names(rast)[[nlyr(rast)]])
   }
 
+
   #Function body
   redVal <- 1
   blueVal <- 0
-  stepSize <- 1/(nlayers(rast) + 1)
+  stepSize <- 1/(nlyr(rast) + 1)
 
-  if(!any(is.na(land))){
-  plotStart <- spplot(rast[[1]],
-                      col.regions = c(rgb(0,0,0,0),
-                                      rgb(redVal,0,blueVal,stepSize)),
-                      cuts = 1, colorkey = FALSE, col="transparent",
-                      main = title,
-                      par.settings = list(mai = c(0,0,0,0)),
-                      maxpixels = maxpixels, sp.layout=list(as(land, "Spatial"), fill=landCol, first=TRUE))
-  } else {
-    plotStart <- spplot(rast[[1]],
-                        col.regions = c(rgb(0,0,0,0),
-                                        rgb(redVal,0,blueVal,stepSize)),
-                        cuts = 1, colorkey = FALSE, col="transparent",
-                        main = title,
-                        par.settings = list(mai = c(0,0,0,0)),
-                        maxpixels = maxpixels)
-  }
+  plot(rast[[1]],
+       col = c(rgb(0,0,0,0),
+               rgb(redVal,0,blueVal,stepSize)),
+       legend = FALSE, mar = c(2,2,3,2), axes = TRUE)
 
-  for(i in 2:nlayers(rast)){
+  for(i in 2:nlyr(rast)){
     redVal <- redVal - stepSize
     blueVal <- blueVal + stepSize
-    plotStart <- plotStart + as.layer(spplot(rast[[i]],
-                                             col.regions = c(rgb(0,0,0,0),
-                                                             rgb(redVal,0,
-                                                                 blueVal,
-                                                                 stepSize)),
-                                             cuts = 1, col="transparent"))
+    plot(rast[[i]], col = c(rgb(0,0,0,0),
+                            rgb(redVal,0,blueVal,stepSize)),
+         legend = FALSE, axes = FALSE, add = TRUE)
   }
 
-  return(plotStart)
+  if(graticule){
+    grat <- graticule(lon = seq(-180, 180, 10), lat = seq(-90,90,10), crs = crs(rast))
+    plot(grat, col="gray50", add = TRUE)
+  }
+
+  if(!any(is.na(land))){
+    if(!("SpatVector" %in% class(land))){
+      land <- vect(land)
+    }
+    plot(land, col = landCol, add = TRUE)
+  }
+
+  title(main = title, cex.main = 1.1)
+
+  finalPlot <- recordPlot()
+
+  return(finalPlot)
 }
