@@ -1,9 +1,9 @@
-library(raster)
+library(terra)
 library(fields)
 
 # interpolateRaster() tests ----
 # Create sample raster
-r <- raster(ncol=10, nrow=10)
+r <- rast(ncol=10, nrow=10)
 values(r) <- 1:100
 
 completeRaster <- r
@@ -26,7 +26,7 @@ test_that("interpolateRaster input warnings behave as expected", {
 })
 
 # Introduce a "hole"
-values(r)[c(12:13, 30)] <- NA
+values(r)[c(45:47, 55:57)] <- NA
 
 test_that("interpolateRaster returns appropriate information", {
  # Execute function
@@ -39,15 +39,15 @@ test_that("interpolateRaster interpolates as expected", {
   interpolatedRaster <- interpolateRaster(r)
 
   # Examine results
-  expect_equal(cellStats(is.na(interpolatedRaster), sum), 0)
-  expect_equal(cellStats(completeRaster, stat = max),
-               cellStats(interpolatedRaster, stat = max))
-  expect_equal(cellStats(completeRaster, stat = min),
-               cellStats(interpolatedRaster, stat = min))
+  expect_true(global(interpolatedRaster, "isNA") == 0)
+  expect_equal(global(completeRaster, max),
+               global(interpolatedRaster, max))
+  expect_equal(global(completeRaster, min),
+               global(interpolatedRaster, min))
 })
 
 # Create sample raster
-r <- raster(ncol=100, nrow=100)
+r <- rast(ncol=100, nrow=100)
 values(r) <- 1:10000
 completeRaster <- r
 
@@ -63,20 +63,20 @@ test_that("fast version of interpolateRaster returns appropriate information", {
 
 test_that("fast version of interpolateRaster interpolates as expected", {
   # Examine results
-  expect_equal(cellStats(is.na(interpolatedRaster), sum), 0)
-  expect_equal(cellStats(completeRaster, stat = max),
-               cellStats(interpolatedRaster, stat = max))
-  expect_equal(cellStats(completeRaster, stat = min),
-               cellStats(interpolatedRaster, stat = min))
+  expect_true(global(completeRaster, "isNA") == 0)
+  expect_equal(global(completeRaster, max),
+               global(interpolatedRaster, max))
+  expect_equal(global(completeRaster, min),
+               global(interpolatedRaster, min))
 })
 
 # smoothRaster() tests ----
 # Create sample raster
-r <- raster(ncol=100, nrow=100)
+r <- rast(ncol=100, nrow=100)
 values(r) <- 1:10000
 
 # Introduce a "bubble"
-values(r)[820:825] <- 9999
+values(r)[c(5030:5050,5130:5150,5230:5250)] <- 9999
 
 test_that("smoothRaster input warnings behave as expected", {
 
@@ -104,13 +104,13 @@ test_that("smoothRaster returns appropriate information", {
 
 test_that("smoothRaster interpolates as expected", {
   # Examine results
-  expect_equal(cellStats(is.na(smoothedRaster), sum), 0)
-  expect_equal(cellStats(r, stat = max),
-               round(cellStats(smoothedRaster, stat = max), digits = 0))
+  expect_true(global(smoothedRaster, "isNA") == 0)
+  expect_equal(global(r, max),
+               round(global(smoothedRaster, max), digits = 0))
 })
 
 # Create sample raster
-r <- raster(ncol=100, nrow=100)
+r <- rast(ncol=100, nrow=100)
 values(r) <- 1:10000
 completeRaster <- r
 
@@ -126,9 +126,9 @@ test_that("fast version of smoothRaster returns appropriate information", {
 
 test_that("fast version of smoothRaster interpolates as expected", {
   # Examine results
-  expect_equal(cellStats(is.na(smoothedRaster), sum), 0)
-  expect_equal(cellStats(smoothedRaster, stat = max),
-               cellStats(smoothedRaster, stat = max))
-  expect_equal(cellStats(smoothedRaster, stat = min),
-               cellStats(smoothedRaster, stat = min))
+  expect_true(global(smoothedRaster, "isNA") == 0)
+  expect_equal(global(smoothedRaster, max),
+               global(smoothedRaster, max))
+  expect_equal(global(smoothedRaster, min),
+               global(smoothedRaster, min))
 })
